@@ -70,7 +70,8 @@ class Form(object):
     """
 
     def __init__(self, config, item=None, dbsession=None, translate=None,
-                 change_page_callback={}, renderers={}, request=None):
+                 change_page_callback={}, renderers={}, request=None,
+                 csrf_token=None):
         """Initialize the form with ``Form`` configuration instance and
         optional an SQLAlchemy mapped object.
 
@@ -88,12 +89,15 @@ class Form(object):
         :request: Current request (See
         http://docs.pylonsproject.org/projects/pyramid/en/latest/api/request.html
         when using in connection with ringo)
+        :csrf_token: Token to which will be included as hidden field in
+        the form to prevent CSRF attacks.
 
         """
         self._config = config
         self._item = item
         self._dbsession = dbsession
         self._request = request
+        self._csrf_token = csrf_token
         if translate:
             self._translate = translate
         else:
@@ -153,7 +157,8 @@ class Form(object):
         serialized = {}
         if not data:
             return serialized
-        for name, field in self._config.get_fields().iteritems():
+        for name, field in self.fields.iteritems():
+            ftype = field.get_type()
             try:
                 value = data.get(name)
                 if value is None:
@@ -170,7 +175,12 @@ class Form(object):
                     try:
                         serialized[name] = value.id
                     except AttributeError:
-                        serialized[name] = value
+                        if ftype == "time":
+                            td = datetime.timedelta(seconds=int(value))
+                            d = datetime.datetime(1, 1, 1) + td
+                            serialized[name] = "%02d:%02d:%02d" % (d.hour, d.minute, d.second)
+                        else:
+                            serialized[name] = value
             except AttributeError:
                 log.warning('Can not get value for field "%s". '
                             'The field is no attribute of the item' % name)
@@ -223,7 +233,20 @@ class Form(object):
         self.current_page = page
         renderer = FormRenderer(self, self._translate)
         form = renderer.render(values)
-        return htmlfill.render(form, values or self.serialize(self.data))
+
+        # If the form is validated (POST) and the form contains no erros
+        # than we use the serialized values of self.data which includes
+        # the converted values.
+        # In all other cases return the self.data attribute which either
+        # has the serialized data of the loaded item (GET) or the
+        # submitted error data on POST.
+        if self.validated and not self.has_errors():
+            values = values or self.serialize(self.data)
+        else:
+            values = values or self.data
+        # Add csrf_token to the values dictionary
+        values['csrf_token'] = self._csrf_token
+        return htmlfill.render(form, values)
 
     def _add_error(self, fieldname, error):
         field = self.get_field(fieldname)
@@ -311,6 +334,16 @@ class Form(object):
             except:
                 msg = "%s is not a valid date format." % value
                 self._add_error(field.name, msg)
+        elif dtype == 'time':
+            try:
+                h, m, s = value.split(':')
+                h = int(h)
+                m = int(m)
+                s = int(s)
+                converted = datetime.timedelta(hours=h, minutes=m, seconds=s).total_seconds()
+            except ValueError:
+                msg = "Value '%s' must be in format 'HH:MM:SS'" % value
+                self._add_error(field.name, msg)
         # Reltation handling
         elif dtype == 'manytoone':
             try:
