@@ -47,6 +47,8 @@ def get_renderer(field, translate):
             return DateFieldRenderer(field, translate)
         elif dtype == "file":
             return FileFieldRenderer(field, translate)
+        elif dtype == "time":
+            return TimeFieldRenderer(field, translate)
     return TextFieldRenderer(field, translate)
 
 
@@ -111,6 +113,10 @@ class FormRenderer(Renderer):
         html.append('<form id="%(id)s" class="%(css)s" '
                     'method="%(method)s" action="%(action)s" '
                     'autocomplete="%(autocomplete)s" enctype="%(enctype)s">' % attr)
+        # Add hidden field with csrf_token if this is not None.
+        if self._form._csrf_token:
+            html.append('<input type="hidden" name="csrf_token" value="%s"/>'
+                        % self._form._csrf_token)
         return "".join(html)
 
     def _render_form_body(self):
@@ -150,9 +156,14 @@ class FieldRenderer(Renderer):
         Renderer.__init__(self)
 
         self._field = field
+        self._config = field._config.renderer
         self.translate = translate
         self.template = None
 
+    def __getattr__(self, name):
+        """Give access to the config values of the renderer"""
+        return getattr(self._config, name)
+
     def _render_label(self):
         template = template_lookup.get_template("label.mako")
         values = {'field': self._field,
@@ -197,6 +208,13 @@ class TextFieldRenderer(FieldRenderer):
         FieldRenderer.__init__(self, field, translate)
         self.template = template_lookup.get_template("textfield.mako")
 
+class TimeFieldRenderer(FieldRenderer):
+    """A Renderer to render simple fa_field elements"""
+
+    def __init__(self, field, translate):
+        FieldRenderer.__init__(self, field, translate)
+        self.template = template_lookup.get_template("timefield.mako")
+
 
 class FileFieldRenderer(FieldRenderer):
     """A Renderer to render simple fa_field elements"""
